@@ -22,7 +22,7 @@ def cape(username):
                     break
 
                 handle.write(block)
-        viewimageonscreen()
+        viewimageonscreen(username)
     except:
         print(f"no cape found on player {username}")
 def dowloadcape(username, file_pach: None):
@@ -58,6 +58,39 @@ def dowloadcape(username, file_pach: None):
         print(f"no cape found on player {username}")
 
 
+def dowloadfullcape(username, file_pach: None):
+    try:
+        str(file_pach)
+        str(username)
+        if(file_pach == None):
+            print("no file pach")
+            exit()
+        if("." in file_pach):
+            print("file pach only. no files like /coolcape.png")
+            exit()
+        else:
+            
+            image = requests.get(f"https://api.capes.dev/load/{username}/minecraft").json()
+
+            view = image['imageUrl']
+            if(str(file_pach).endswith("/") == False):
+                file_pach = str(file_pach) + "/"
+            with open(f'{file_pach}full_cape.png', 'wb') as handle:
+                response = requests.get(view + ".png", stream=True)
+
+                if not response.ok:
+                    print(response)
+
+                for block in response.iter_content(1024):
+                    if not block:
+                        break
+
+                    handle.write(block)
+        print(f"saved in '{file_pach}full_cape.png'")
+    except:
+        print(f"no cape found on player {username}")
+
+
 
  
 # # Opens a image in RGB mode
@@ -103,7 +136,7 @@ def dowloadcape(username, file_pach: None):
 # canvas.create_image(10,1, anchor=NW, image=new_image)
 
 #win.mainloop()
-def sing():
+def sing(username):
     # Opens a image in RGB mode
     im = Image.open("pic1.png")
     
@@ -145,10 +178,11 @@ def sing():
 
     #Add image to the Canvas Items
     canvas.create_image(10,1, anchor=NW, image=new_image)
+    win.title(username)
     win.mainloop()
     os.remove("pic1.png")
 
 
-def viewimageonscreen():
-    thread = Thread(target=sing)
+def viewimageonscreen(username):
+    thread = Thread(target=sing, args=username)
     thread.start()
\ No newline at end of file
